@@ -18,6 +18,7 @@ import operator
 import sys
 from functools import cached_property
 from dataclasses import dataclass, field
+from types import MethodDescriptorType, ModuleType
 
 from IPython.utils.docs import GENERATING_DOCUMENTATION
 from IPython.utils.decorators import undoc
@@ -508,9 +509,6 @@ def eval_node(node: Union[ast.AST, None], context: EvaluationContext):
         return all_true
     if isinstance(node, ast.Constant):
         return node.value
-    if isinstance(node, ast.Index):
-        # deprecated since Python 3.9
-        return eval_node(node.value, context)  # pragma: no cover
     if isinstance(node, ast.Tuple):
         return tuple(eval_node(e, context) for e in node.elts)
     if isinstance(node, ast.List):
@@ -530,9 +528,6 @@ def eval_node(node: Union[ast.AST, None], context: EvaluationContext):
             eval_node(node.upper, context),
             eval_node(node.step, context),
         )
-    if isinstance(node, ast.ExtSlice):
-        # deprecated since Python 3.9
-        return tuple([eval_node(dim, context) for dim in node.dims])  # pragma: no cover
     if isinstance(node, ast.UnaryOp):
         value = eval_node(node.operand, context)
         dunders = _find_dunder(node.op, UNARY_OP_DUNDERS)
@@ -636,7 +631,6 @@ set_non_mutating_methods = set(dir(set)) & set(dir(frozenset))
 
 
 dict_keys: Type[collections.abc.KeysView] = type({}.keys())
-method_descriptor: Any = type(list.copy)
 
 NUMERICS = {int, float, complex}
 
@@ -685,7 +679,8 @@ BUILTIN_GETATTR: Set[MayHaveGetattr] = {
     type,  # `type` handles a lot of generic cases, e.g. numbers as in `int.real`.
     *NUMERICS,
     dict_keys,
-    method_descriptor,
+    MethodDescriptorType,
+    ModuleType,
 }
 
 
